import { defineNuxtModule, createResolver, useLogger, addPlugin, addImportsDir } from '@nuxt/kit';
import { defu } from 'defu';

const MODULE_NAME = "nuxt-laravel-echo";
const defaultModuleOptions = {
  broadcaster: "reverb",
  host: "localhost",
  port: 8080,
  scheme: "https",
  transports: ["ws", "wss"],
  authentication: {
    baseUrl: "http://localhost:80",
    authEndpoint: "/broadcasting/auth",
    csrfEndpoint: "/sanctum/csrf-cookie",
    csrfCookie: "XSRF-TOKEN",
    csrfHeader: "X-XSRF-TOKEN"
  },
  logLevel: 3
};
const module = defineNuxtModule({
  meta: {
    name: MODULE_NAME,
    configKey: "echo"
  },
  defaults: defaultModuleOptions,
  setup(_options, _nuxt) {
    const resolver = createResolver(import.meta.url);
    const logger = useLogger(MODULE_NAME, { level: _options.logLevel });
    _nuxt.options.build.transpile.push(resolver.resolve("./runtime"));
    _nuxt.options.runtimeConfig.public.echo = defu(
      _nuxt.options.runtimeConfig.public.echo,
      _options
    );
    addPlugin(resolver.resolve("./runtime/plugin.client"));
    addImportsDir(resolver.resolve("./runtime/composables"));
    logger.info("Laravel Echo module initialized!");
  }
});

export { module as default };
